@@ -1,12 +1,12 @@
 from .base import ObjectBase
-from .list import List
+from .list import ObjectList
 from .order_line import OrderLine
 
 
 class Refund(ObjectBase):
     @classmethod
     def get_resource_class(cls, client):
-        from ..resources.refunds import Refunds
+        from ..resources import Refunds
 
         return Refunds(client)
 
@@ -29,6 +29,10 @@ class Refund(ObjectBase):
     def amount(self):
         return self._get_property("amount")
 
+    @property
+    def settlement_id(self):
+        return self._get_property("settlementId")
+
     @property
     def settlement_amount(self):
         return self._get_property("settlementAmount")
@@ -51,7 +55,7 @@ class Refund(ObjectBase):
             },
             "count": len(lines),
         }
-        return List(result, OrderLine, self.client)
+        return ObjectList(result, OrderLine, self.client)
 
     @property
     def payment_id(self):
@@ -71,24 +75,21 @@ class Refund(ObjectBase):
 
     # documented _links
 
-    @property
-    def payment(self):
+    def get_payment(self):
         """Return the payment for this refund."""
         return self.client.payments.get(self.payment_id)
 
-    # @property
-    # def settlement(self):
-    #     """
-    #     Return the settlement for this refund.
+    def get_settlement(self):
+        """Return the settlement for this refund."""
+        if self.settlement_id:
+            return self.client.settlements.get(self.settlement_id)
+        return None
 
-    #     TODO: Before we can return an Settlement object, we need to implement the Setlement API.
-    #     """
-    #     pass
-
-    @property
-    def order(self):
+    def get_order(self):
         """Return the order for this refund."""
-        return self.client.orders.get(self.order_id)
+        if self.order_id:
+            return self.client.orders.get(self.order_id)
+        return None
 
     # additional methods
 
